Object.defineProperty(exports, '__esModule', { value: true });

const preprocessors = require('./preprocessors.js');

const DEFAULT_SENTRY_OPTIONS = {
  componentTracking: preprocessors.defaultComponentTrackingOptions,
};

/**
 * Add Sentry options to the Svelte config to be exported from the user's `svelte.config.js` file.
 *
 * @param originalConfig The existing config to be exported prior to adding Sentry
 * @param sentryOptions The configuration of the Sentry-added options
 *
 * @return The wrapped and modified config to be exported
 */
function withSentryConfig(
  originalConfig,
  sentryOptions,
) {
  const mergedOptions = {
    ...DEFAULT_SENTRY_OPTIONS,
    ...sentryOptions,
  };

  const originalPreprocessors = getOriginalPreprocessorArray(originalConfig);

  // Map is insertion-order-preserving. It's important to add preprocessors
  // to this map in the right order we want to see them being executed.
  // see: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Map
  const sentryPreprocessors = new Map();

  const shouldTrackComponents = mergedOptions.componentTracking && mergedOptions.componentTracking.trackComponents;
  if (shouldTrackComponents) {
    const firstPassPreproc = preprocessors.componentTrackingPreprocessor(mergedOptions.componentTracking);
    sentryPreprocessors.set(firstPassPreproc.sentryId || '', firstPassPreproc);
  }

  // We prioritize user-added preprocessors, so we don't insert sentry processors if they
  // have already been added by users.
  originalPreprocessors.forEach((p) => {
    if (p.sentryId) {
      sentryPreprocessors.delete(p.sentryId);
    }
  });

  const mergedPreprocessors = [...sentryPreprocessors.values(), ...originalPreprocessors];

  return {
    ...originalConfig,
    preprocess: mergedPreprocessors,
  };
}

/**
 * Standardizes the different ways the user-provided preprocessor option can be specified.
 * Users can specify an array of preprocessors, a single one or no preprocessor.
 *
 * @param originalConfig the user-provided svelte config oject
 * @return an array of preprocessors or an empty array if no preprocessors were specified
 */
function getOriginalPreprocessorArray(originalConfig) {
  if (originalConfig.preprocess) {
    if (Array.isArray(originalConfig.preprocess)) {
      return originalConfig.preprocess;
    }
    return [originalConfig.preprocess];
  }
  return [];
}

exports.withSentryConfig = withSentryConfig;
//# sourceMappingURL=config.js.map
